Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(574)

Unified Diff: generated/googleapis/lib/plus/v1.dart

Issue 1078053002: Roll of googleapis as of 4/7/2015. (Closed) Base URL: https://github.com/dart-lang/googleapis.git@master
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « generated/googleapis/lib/pagespeedonline/v2.dart ('k') | generated/googleapis/lib/plusdomains/v1.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: generated/googleapis/lib/plus/v1.dart
diff --git a/generated/googleapis/lib/plus/v1.dart b/generated/googleapis/lib/plus/v1.dart
index 3aab278c5b2a58623d6d5abddd1c506efbcacc8b..7f573f1668a692a00aba74896a4eb8fc631a32d7 100644
--- a/generated/googleapis/lib/plus/v1.dart
+++ b/generated/googleapis/lib/plus/v1.dart
@@ -1,17 +1,20 @@
+// This is a generated file (see the discoveryapis_generator project).
+
library googleapis.plus.v1;
-import "dart:core" as core;
-import "dart:collection" as collection_1;
-import "dart:async" as async;
-import "dart:convert" as convert;
+import 'dart:core' as core;
+import 'dart:collection' as collection_1;
+import 'dart:async' as async;
+import 'dart:convert' as convert;
-import "package:crypto/crypto.dart" as crypto;
+import 'package:_discoveryapis_commons/_discoveryapis_commons.dart' as commons;
+import 'package:crypto/crypto.dart' as crypto;
import 'package:http/http.dart' as http;
-import '../src/common_internal.dart' as common_internal;
-import '../common/common.dart' as common;
-export '../common/common.dart' show ApiRequestError;
-export '../common/common.dart' show DetailedApiRequestError;
+export 'package:_discoveryapis_commons/_discoveryapis_commons.dart' show
+ ApiRequestError, DetailedApiRequestError;
+
+const core.String USER_AGENT = 'dart-api-client plus/v1';
/**
* The Google+ API enables developers to build on top of the Google+ platform.
@@ -30,7 +33,7 @@ class PlusApi {
static const UserinfoProfileScope = "https://www.googleapis.com/auth/userinfo.profile";
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
ActivitiesResourceApi get activities => new ActivitiesResourceApi(_requester);
CommentsResourceApi get comments => new CommentsResourceApi(_requester);
@@ -38,15 +41,14 @@ class PlusApi {
PeopleResourceApi get people => new PeopleResourceApi(_requester);
PlusApi(http.Client client, {core.String rootUrl: "https://www.googleapis.com/", core.String servicePath: "plus/v1/"}) :
- _requester = new common_internal.ApiRequester(client, rootUrl, servicePath);
+ _requester = new commons.ApiRequester(client, rootUrl, servicePath, USER_AGENT);
}
-/** Not documented yet. */
class ActivitiesResourceApi {
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
- ActivitiesResourceApi(common_internal.ApiRequester client) :
+ ActivitiesResourceApi(commons.ApiRequester client) :
_requester = client;
/**
@@ -58,7 +60,7 @@ class ActivitiesResourceApi {
*
* Completes with a [Activity].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -69,7 +71,7 @@ class ActivitiesResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (activityId == null) {
@@ -77,7 +79,7 @@ class ActivitiesResourceApi {
}
- _url = 'activities/' + common_internal.Escaper.ecapeVariable('$activityId');
+ _url = 'activities/' + commons.Escaper.ecapeVariable('$activityId');
var _response = _requester.request(_url,
"GET",
@@ -113,7 +115,7 @@ class ActivitiesResourceApi {
*
* Completes with a [ActivityFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -124,7 +126,7 @@ class ActivitiesResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (userId == null) {
@@ -141,7 +143,7 @@ class ActivitiesResourceApi {
}
- _url = 'people/' + common_internal.Escaper.ecapeVariable('$userId') + '/activities/' + common_internal.Escaper.ecapeVariable('$collection');
+ _url = 'people/' + commons.Escaper.ecapeVariable('$userId') + '/activities/' + commons.Escaper.ecapeVariable('$collection');
var _response = _requester.request(_url,
"GET",
@@ -180,7 +182,7 @@ class ActivitiesResourceApi {
*
* Completes with a [ActivityFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -191,7 +193,7 @@ class ActivitiesResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (query == null) {
@@ -227,11 +229,10 @@ class ActivitiesResourceApi {
}
-/** Not documented yet. */
class CommentsResourceApi {
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
- CommentsResourceApi(common_internal.ApiRequester client) :
+ CommentsResourceApi(commons.ApiRequester client) :
_requester = client;
/**
@@ -243,7 +244,7 @@ class CommentsResourceApi {
*
* Completes with a [Comment].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -254,7 +255,7 @@ class CommentsResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (commentId == null) {
@@ -262,7 +263,7 @@ class CommentsResourceApi {
}
- _url = 'comments/' + common_internal.Escaper.ecapeVariable('$commentId');
+ _url = 'comments/' + commons.Escaper.ecapeVariable('$commentId');
var _response = _requester.request(_url,
"GET",
@@ -297,7 +298,7 @@ class CommentsResourceApi {
*
* Completes with a [CommentFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -308,7 +309,7 @@ class CommentsResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (activityId == null) {
@@ -325,7 +326,7 @@ class CommentsResourceApi {
}
- _url = 'activities/' + common_internal.Escaper.ecapeVariable('$activityId') + '/comments';
+ _url = 'activities/' + commons.Escaper.ecapeVariable('$activityId') + '/comments';
var _response = _requester.request(_url,
"GET",
@@ -340,11 +341,10 @@ class CommentsResourceApi {
}
-/** Not documented yet. */
class MomentsResourceApi {
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
- MomentsResourceApi(common_internal.ApiRequester client) :
+ MomentsResourceApi(commons.ApiRequester client) :
_requester = client;
/**
@@ -366,7 +366,7 @@ class MomentsResourceApi {
*
* Completes with a [Moment].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -377,7 +377,7 @@ class MomentsResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (request != null) {
@@ -394,7 +394,7 @@ class MomentsResourceApi {
}
- _url = 'people/' + common_internal.Escaper.ecapeVariable('$userId') + '/moments/' + common_internal.Escaper.ecapeVariable('$collection');
+ _url = 'people/' + commons.Escaper.ecapeVariable('$userId') + '/moments/' + commons.Escaper.ecapeVariable('$collection');
var _response = _requester.request(_url,
"POST",
@@ -434,7 +434,7 @@ class MomentsResourceApi {
*
* Completes with a [MomentsFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -445,7 +445,7 @@ class MomentsResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (userId == null) {
@@ -468,7 +468,7 @@ class MomentsResourceApi {
}
- _url = 'people/' + common_internal.Escaper.ecapeVariable('$userId') + '/moments/' + common_internal.Escaper.ecapeVariable('$collection');
+ _url = 'people/' + commons.Escaper.ecapeVariable('$userId') + '/moments/' + commons.Escaper.ecapeVariable('$collection');
var _response = _requester.request(_url,
"GET",
@@ -487,7 +487,7 @@ class MomentsResourceApi {
*
* [id] - The ID of the moment to delete.
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -498,7 +498,7 @@ class MomentsResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (id == null) {
@@ -507,7 +507,7 @@ class MomentsResourceApi {
_downloadOptions = null;
- _url = 'moments/' + common_internal.Escaper.ecapeVariable('$id');
+ _url = 'moments/' + commons.Escaper.ecapeVariable('$id');
var _response = _requester.request(_url,
"DELETE",
@@ -522,11 +522,10 @@ class MomentsResourceApi {
}
-/** Not documented yet. */
class PeopleResourceApi {
- final common_internal.ApiRequester _requester;
+ final commons.ApiRequester _requester;
- PeopleResourceApi(common_internal.ApiRequester client) :
+ PeopleResourceApi(commons.ApiRequester client) :
_requester = client;
/**
@@ -541,7 +540,7 @@ class PeopleResourceApi {
*
* Completes with a [Person].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -552,7 +551,7 @@ class PeopleResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (userId == null) {
@@ -560,7 +559,7 @@ class PeopleResourceApi {
}
- _url = 'people/' + common_internal.Escaper.ecapeVariable('$userId');
+ _url = 'people/' + commons.Escaper.ecapeVariable('$userId');
var _response = _requester.request(_url,
"GET",
@@ -604,7 +603,7 @@ class PeopleResourceApi {
*
* Completes with a [PeopleFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -615,7 +614,7 @@ class PeopleResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (userId == null) {
@@ -635,7 +634,7 @@ class PeopleResourceApi {
}
- _url = 'people/' + common_internal.Escaper.ecapeVariable('$userId') + '/people/' + common_internal.Escaper.ecapeVariable('$collection');
+ _url = 'people/' + commons.Escaper.ecapeVariable('$userId') + '/people/' + commons.Escaper.ecapeVariable('$collection');
var _response = _requester.request(_url,
"GET",
@@ -671,7 +670,7 @@ class PeopleResourceApi {
*
* Completes with a [PeopleFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -682,7 +681,7 @@ class PeopleResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (activityId == null) {
@@ -699,7 +698,7 @@ class PeopleResourceApi {
}
- _url = 'activities/' + common_internal.Escaper.ecapeVariable('$activityId') + '/people/' + common_internal.Escaper.ecapeVariable('$collection');
+ _url = 'activities/' + commons.Escaper.ecapeVariable('$activityId') + '/people/' + commons.Escaper.ecapeVariable('$collection');
var _response = _requester.request(_url,
"GET",
@@ -734,7 +733,7 @@ class PeopleResourceApi {
*
* Completes with a [PeopleFeed].
*
* Completes with a [common.ApiRequestError] if the API endpoint returned an
* error.
*
* If the used [http.Client] completes with an error when making a REST call,
@@ -745,7 +744,7 @@ class PeopleResourceApi {
var _queryParams = new core.Map();
var _uploadMedia = null;
var _uploadOptions = null;
- var _downloadOptions = common.DownloadOptions.Metadata;
+ var _downloadOptions = commons.DownloadOptions.Metadata;
var _body = null;
if (query == null) {
@@ -779,7 +778,6 @@ class PeopleResourceApi {
-/** Not documented yet. */
class Acl {
/** Description of the access granted, suitable for display. */
core.String description;
@@ -1209,7 +1207,6 @@ class ActivityObjectAttachmentsThumbnailsImage {
}
-/** Not documented yet. */
class ActivityObjectAttachmentsThumbnails {
/** Potential name of the thumbnail. */
core.String description;
@@ -1251,7 +1248,6 @@ class ActivityObjectAttachmentsThumbnails {
}
-/** Not documented yet. */
class ActivityObjectAttachments {
/**
* If the attachment is an article, this property contains a snippet of text
@@ -1606,7 +1602,6 @@ class ActivityProvider {
}
-/** Not documented yet. */
class Activity {
/** Identifies who has access to see this activity. */
Acl access;
@@ -1824,7 +1819,6 @@ class Activity {
}
-/** Not documented yet. */
class ActivityFeed {
/** ETag of this response for caching purposes. */
core.String etag;
@@ -2012,7 +2006,6 @@ class CommentActor {
}
-/** Not documented yet. */
class CommentInReplyTo {
/** The ID of the activity. */
core.String id;
@@ -2118,7 +2111,6 @@ class CommentPlusoners {
}
-/** Not documented yet. */
class Comment {
/** The person who posted this comment. */
CommentActor actor;
@@ -2242,7 +2234,6 @@ class Comment {
}
-/** Not documented yet. */
class CommentFeed {
/** ETag of this response for caching purposes. */
core.String etag;
@@ -2339,7 +2330,6 @@ class CommentFeed {
}
-/** Not documented yet. */
class ItemScope {
/** The subject matter of the content. */
ItemScope about;
@@ -2921,7 +2911,6 @@ class ItemScope {
}
-/** Not documented yet. */
class Moment {
/** The moment ID. */
core.String id;
@@ -3012,7 +3001,6 @@ class Moment {
}
-/** Not documented yet. */
class MomentsFeed {
/** ETag of this response for caching purposes. */
core.String etag;
@@ -3108,7 +3096,6 @@ class MomentsFeed {
}
-/** Not documented yet. */
class PeopleFeed {
/** ETag of this response for caching purposes. */
core.String etag;
@@ -3375,7 +3362,6 @@ class PersonCover {
}
-/** Not documented yet. */
class PersonEmails {
/**
* The type of address. Possible values include, but are not limited to, the
@@ -3523,7 +3509,6 @@ class PersonName {
}
-/** Not documented yet. */
class PersonOrganizations {
/** The department within the organization. Deprecated. */
core.String department;
@@ -3629,7 +3614,6 @@ class PersonOrganizations {
}
-/** Not documented yet. */
class PersonPlacesLived {
/** If "true", this place of residence is this person's primary residence. */
core.bool primary;
@@ -3665,7 +3649,6 @@ class PersonPlacesLived {
}
-/** Not documented yet. */
class PersonUrls {
/** The label of the URL. */
core.String label;
@@ -3714,7 +3697,6 @@ class PersonUrls {
}
-/** Not documented yet. */
class Person {
/** A short biography for this person. */
core.String aboutMe;
@@ -4101,7 +4083,6 @@ class PlacePosition {
}
-/** Not documented yet. */
class Place {
/** The physical address of the place. */
PlaceAddress address;
@@ -4161,7 +4142,6 @@ class Place {
}
-/** Not documented yet. */
class PlusAclentryResource {
/** A descriptive name for this entry. Suitable for display. */
core.String displayName;
@@ -4214,5 +4194,3 @@ class PlusAclentryResource {
return _json;
}
}
-
-
« no previous file with comments | « generated/googleapis/lib/pagespeedonline/v2.dart ('k') | generated/googleapis/lib/plusdomains/v1.dart » ('j') | no next file with comments »

Powered by Google App Engine
@@ -58,7 +60,7 @@ class ActivitiesResourceApi {
* Completes with a [Activity].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -113,7 +115,7 @@ class ActivitiesResourceApi {
* Completes with a [ActivityFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -180,7 +182,7 @@ class ActivitiesResourceApi {
* Completes with a [ActivityFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -243,7 +244,7 @@ class CommentsResourceApi {
* Completes with a [Comment].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -297,7 +298,7 @@ class CommentsResourceApi {
* Completes with a [CommentFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -366,7 +366,7 @@ class MomentsResourceApi {
* Completes with a [Moment].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -434,7 +434,7 @@ class MomentsResourceApi {
* Completes with a [MomentsFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -487,7 +487,7 @@ class MomentsResourceApi {
* [id] - The ID of the moment to delete.
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -541,7 +540,7 @@ class PeopleResourceApi {
* Completes with a [Person].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -604,7 +603,7 @@ class PeopleResourceApi {
* Completes with a [PeopleFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -671,7 +670,7 @@ class PeopleResourceApi {
* Completes with a [PeopleFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
@@ -734,7 +733,7 @@ class PeopleResourceApi {
* Completes with a [PeopleFeed].
*
- * Completes with a [common.ApiRequestError] if the API endpoint returned an
+ * Completes with a [commons.ApiRequestError] if the API endpoint returned an
* error.
*
This is Rietveld 408576698